Users and Groups
================
|
Users exist within the scope of an Organization within Control Hub. Invite other users to join your organization so that
you can collaborate on building jobs, pipelines, and other activities. The SDK allows you to create new users, delete
existing users, update current users, and more.

Like users, groups also exist within the scope of an organization within Control Hub. Groups encompass 1 or more users,
and help further filter and categorize users within an organization. The SDK allows you to create groups and assign
users to a group so that you can easily manage roles and permissions.

Use roles and permissions to determine the level of access a user or group has.

For more details, refer to the `StreamSets Platform Documentation <https://docs.streamsets.com/portal/platform-controlhub/controlhub/UserGuide/OrganizationSecurity/UsersGroups_title.html>`_.

.. toctree::
   :maxdepth: 3
   :hidden:

   managing_users_and_groups
   roles
   permissions
